@@ -21,7 +21,11 @@ from aleph_alpha_client.summarization import SummarizationRequest, Summarization
 
 class AlephAlphaModel:
     def __init__(
-        self, client: AlephAlphaClient, model_name: str, hosting: Optional[str] = None
+        self,
+        client: AlephAlphaClient,
+        model_name: Optional[str] = None,
+        hosting: Optional[str] = None,
+        checkpoint_name: Optional[str] = None,
     ) -> None:
         """
         Construct a context object for a specific model.
@@ -30,9 +34,11 @@ class AlephAlphaModel:
             client (AlephAlphaClient, required):
                 An AlephAlphaClient object that holds the API host information and user credentials.
 
-            model_name (str, required):
+            model_name (str, optional, default None):
                 Name of model to use. A model name refers to a model architecture (number of parameters among others). Always the latest version of model is used. The model output contains information as to the model version.
 
+                Need to set exactly one of model_name and checkpoint_name.
+
             hosting (str, optional, default None):
                 Determines in which datacenters the request may be processed.
                 You can either set the parameter to "aleph-alpha" or omit it (defaulting to None).
@@ -42,31 +48,50 @@ class AlephAlphaModel:
 
                 Setting it to "aleph-alpha" allows us to only process the request in our own datacenters.
                 Choose this option for maximal data privacy.
+
+            checkpoint_name (str, optional, default None):
+                Name of checkpoint to use. A checkpoint name refers to a language model architecture (number of parameters among others).
+
+                Need to set exactly one of model_name and checkpoint_name.
         """
 
+        if (model_name is None and checkpoint_name is None) or (
+            model_name is not None and checkpoint_name is not None
+        ):
+            raise ValueError(
+                "Need to set exactly one of model_name and checkpoint_name."
+            )
+
         self.client = client
         self.model_name = model_name
         self.hosting = hosting
+        self.checkpoint_name = checkpoint_name
 
     def complete(self, request: CompletionRequest) -> CompletionResponse:
         response_json = self.client.complete(
-            model=self.model_name, hosting=self.hosting, **self.as_request_dict(request)
+            model=self.model_name,
+            hosting=self.hosting,
+            **self.as_request_dict(request),
+            checkpoint=self.checkpoint_name
         )
         return CompletionResponse.from_json(response_json)
 
     def tokenize(self, request: TokenizationRequest) -> TokenizationResponse:
-        response_json = self.client.tokenize(model=self.model_name, **request._asdict())
+        response_json = self.client.tokenize(model=self.model_name, **request._asdict(), checkpoint=self.checkpoint_name)
         return TokenizationResponse.from_json(response_json)
 
     def detokenize(self, request: DetokenizationRequest) -> DetokenizationResponse:
         response_json = self.client.detokenize(
-            model=self.model_name, **request._asdict()
+            model=self.model_name, **request._asdict(), checkpoint=self.checkpoint_name
         )
         return DetokenizationResponse.from_json(response_json)
 
     def embed(self, request: EmbeddingRequest) -> EmbeddingResponse:
         response_json = self.client.embed(
-            model=self.model_name, hosting=self.hosting, **self.as_request_dict(request)
+            model=self.model_name,
+            hosting=self.hosting,
+            **self.as_request_dict(request),
+            checkpoint=self.checkpoint_name
         )
         return EmbeddingResponse.from_json(response_json)
 
@@ -74,30 +99,45 @@ class AlephAlphaModel:
         self, request: SemanticEmbeddingRequest
     ) -> SemanticEmbeddingResponse:
         response_json = self.client.semantic_embed(
-            model=self.model_name, hosting=self.hosting, request=request
+            model=self.model_name,
+            hosting=self.hosting,
+            request=request,
+            checkpoint=self.checkpoint_name,
         )
         return SemanticEmbeddingResponse.from_json(response_json)
 
     def evaluate(self, request: EvaluationRequest) -> EvaluationResponse:
         response_json = self.client.evaluate(
-            model=self.model_name, hosting=self.hosting, **self.as_request_dict(request)
+            model=self.model_name,
+            hosting=self.hosting,
+            **self.as_request_dict(request),
+            checkpoint=self.checkpoint_name
         )
         return EvaluationResponse.from_json(response_json)
 
     def qa(self, request: QaRequest) -> QaResponse:
         response_json = self.client.qa(
-            model=self.model_name, hosting=self.hosting, **request._asdict()
+            model=self.model_name,
+            hosting=self.hosting,
+            **request._asdict(),
+            checkpoint=self.checkpoint_name
         )
         return QaResponse.from_json(response_json)
 
     def _explain(self, request: ExplanationRequest) -> Mapping[str, Any]:
         return self.client._explain(
-            model=self.model_name, hosting=self.hosting, request=request
+            model=self.model_name,
+            hosting=self.hosting,
+            request=request,
+            checkpoint=self.checkpoint_name,
         )
 
     def summarize(self, request: SummarizationRequest) -> SummarizationResponse:
         response_json = self.client.summarize(
-            self.model_name, request, hosting=self.hosting
+            self.model_name,
+            request,
+            hosting=self.hosting,
+            checkpoint=self.checkpoint_name,
         )
         return SummarizationResponse.from_json(response_json)
 
